Massimo -

Here is for everyone; I'm sending this separately too.

Yarko

=== modified file 'docs/t2.tex'
--- docs/t2.tex 2008-10-22 02:26:42 +0000
+++ docs/t2.tex 2008-11-18 18:55:36 +0000
@@ -40,7 +40,7 @@
 \end{verbatim}}

 \noindent Video Tutorial (old):
-{\footnotesize
+{\footnotesize
 \begin{verbatim}
 http://www.vimeo.com/1790354
 \end{verbatim}}
@@ -606,9 +606,9 @@

 Both of them take a list of tables and some optional named arguments. For
example:
 \begin{lstlisting}
-{{=t2.itemize(db.mytable,query=db.mytable.id>0,orderby=db.mytable.id)}}
+{{=t2.itemize(db.mytable,query=db.mytable.id>0,orderby=db.mytable.id
,nitems=my_page_size)}}
 \end{lstlisting}
-displays all records that match the query. If no \ttt{limitby} is
specified, this control paginates the items, 25 per page.
+displays all records that match the query. If  \ttt{nitems} is not
specified, 25 is the default number of items per page.

 \begin{lstlisting}
 {{=t2.search(db.mytable)}}

=== modified file 'modules/t2.py'
--- modules/t2.py 2008-11-09 06:45:34 +0000
+++ modules/t2.py 2008-11-18 18:50:32 +0000
@@ -491,7 +491,8 @@
     def itemize(self,*tables,**opts):
         """
         Lists all records from tables.
-        opts include: query, orderby, limitby
+        opts include: query, orderby, nitems
+  where nitems is items per page;
         """
         ### FIX - ADD PAGINATION BUTTONS
         import re

--~--~---------~--~----~------------~-------~--~----~
You received this message because you are subscribed to the Google Groups 
"web2py Web Framework" group.
To post to this group, send email to web2py@googlegroups.com
To unsubscribe from this group, send email to [EMAIL PROTECTED]
For more options, visit this group at 
http://groups.google.com/group/web2py?hl=en
-~----------~----~----~----~------~----~------~--~---

Reply via email to